Data anomalies
==============

This list chronologically records anomalies or large outages in the PUNCH data by spacecraft.
This list may not be exhaustive. If you see additional issues, please report them by opening an issue or PR.

NFI
---

- **June 18, 2025 - present**: many images being lost due to spacecraft software issue
- **May 21, 2025 - present**: NFI images saturate periodically over Antarctica due to orbit alignment

WFI-1
-----

None reported.

WFI-2
-----

- **June 15, 2025 - June 18, 2025**: pointing drifts in images causing star trails

WFI-3
-----

None reported.
